@@ -3,6 +3,7 @@
 
 #include <gtk/gtk.h>
 #include "service-info.h"
+#include <mojito-client/mojito-client.h>
 
 G_BEGIN_DECLS
 
@@ -11,9 +12,9 @@ G_BEGIN_DECLS
   (G_TYPE_CHECK_INSTANCE_CAST ((obj), BISHO_TYPE_PANE, BishoPane))
 #define BISHO_PANE_CLASS(klass)                                         \
   (G_TYPE_CHECK_CLASS_CAST ((klass), BISHO_TYPE_PANE, BishoPaneClass))
-#define IS_BISHO_PANE(obj)                              \
+#define BISHO_IS_PANE(obj)                              \
   (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BISHO_TYPE_PANE))
-#define IS_BISHO_PANE_CLASS(klass)                      \
+#define BISHO_IS_PANE_CLASS(klass)                      \
   (G_TYPE_CHECK_CLASS_TYPE ((klass), BISHO_TYPE_PANE))
 #define BISHO_PANE_GET_CLASS(obj)                                       \
    (G_TYPE_INSTANCE_GET_CLASS ((obj), BISHO_TYPE_PANE, BishoPaneClass))
@@ -22,11 +23,21 @@ typedef struct _BishoPane BishoPane;
 typedef struct _BishoPaneClass BishoPaneClass;
 
 struct _BishoPane {
-  GtkTable parent;
+  GtkVBox parent;
+  MojitoClient *mojito;
+  ServiceInfo *info;
+  GtkWidget *description;
+  GtkWidget *banner;
+  GtkWidget *banner_label;
+  GtkWidget *user_box;
+  GtkWidget *user_icon;
+  GtkWidget *user_name;
+  GtkWidget *content;
+  GtkWidget *disclaimer;
 };
 
 struct _BishoPaneClass {
-  GtkTableClass parent_class;
+  GtkVBoxClass parent_class;
   void (*continue_auth) (BishoPane *pane, GHashTable *params);
 };
 
@@ -34,7 +45,13 @@ GType bisho_pane_get_type (void) G_GNUC_CONST;
 
 void bisho_pane_continue_auth (BishoPane *pane, GHashTable *params);
 
-GtkWidget * bisho_pane_make_disclaimer_label (ServiceInfo *info);
+void bisho_pane_set_banner (BishoPane *pane, const char *message);
+
+void bisho_pane_set_banner_error (BishoPane *pane, const GError *error);
+
+void bisho_pane_set_user (BishoPane *pane, const char *icon, const char *username);
+
+void bisho_pane_follow_connected (BishoPane *pane, GtkWidget *widget);
 
 G_END_DECLS
 
