@@ -21,37 +21,31 @@
 #include <gtk/gtk.h>
 #include <mojito-client/mojito-client.h>
 #include "mux-expanding-item.h"
-#include "mux-banner.h"
-#include "mux-window.h"
 #include "bisho-window.h"
 #include "bisho-utils.h"
 #include "service-info.h"
-#include "entry.h"
 #include "bisho-pane-oauth.h"
 #include "bisho-pane-flickr.h"
-#include "bisho-facebook-pane.h"
+#include "bisho-pane-username.h"
 
 struct _BishoWindowPrivate {
   MojitoClient *client;
   GtkWidget *master_box;
-  GtkWidget *banner;
   /* Hash of string (identifier) to pane widget */
   GHashTable *panes;
 };
 
 #define GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), BISHO_TYPE_WINDOW, BishoWindowPrivate))
 
-G_DEFINE_TYPE (BishoWindow, bisho_window, MUX_TYPE_WINDOW);
+G_DEFINE_TYPE (BishoWindow, bisho_window, GTK_TYPE_WINDOW);
 
 static void
 construct_ui (BishoWindow *window, const char *service_name)
 {
   ServiceInfo *info;
-  GtkWidget *expander, *label, *banner;
+  GtkWidget *expander, *pane;
   GtkBox *box;
   MuxExpandingItem *m;
-  GtkTextBuffer *buffer;
-  GtkTextIter end;
 
   g_assert (window);
   g_assert (service_name);
@@ -74,95 +68,34 @@ construct_ui (BishoWindow *window, const char *service_name)
   gtk_container_set_border_width (GTK_CONTAINER (box), 8);
   gtk_box_set_spacing (box, 8);
 
-  banner = mux_banner_new ();
-  gtk_widget_show (banner);
-  gtk_box_pack_start (box, banner, FALSE, FALSE, 0);
-  buffer = mux_banner_get_buffer (MUX_BANNER (banner));
-
-  if (info->description) {
-    gtk_text_buffer_get_end_iter (buffer, &end);
-    gtk_text_buffer_insert (buffer, &end, info->description, -1);
-  }
-
-  if (info->link) {
-    GtkTextTag *tag;
-
-    gtk_text_buffer_get_end_iter (buffer, &end);
-
-    tag = mux_banner_create_link_tag (MUX_BANNER (banner), info->link);
-
-    gtk_text_buffer_insert (buffer, &end, "  ", -1);
-    gtk_text_buffer_insert_with_tags (buffer, &end,
-                                      _("Launch site for more information."), -1,
-                                      tag, NULL);
-  }
-
   switch (info->auth) {
   case AUTH_USERNAME:
-    {
-      GtkWidget *table, *entry;
-
-      table = gtk_table_new (1, 2, FALSE);
-
-      label = gtk_label_new (_("Username:"));
-      gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
-
-      entry = new_entry_from_gconf (window, info, "user");
-      gtk_table_attach_defaults (GTK_TABLE (table), entry, 1, 2, 0, 1);
-
-      gtk_widget_show_all (table);
-      gtk_box_pack_start (GTK_BOX (box), table, FALSE, FALSE, 0);
-    }
+    pane = bisho_pane_username_new (info);
+    bisho_pane_username_add_entry
+      (BISHO_PANE_USERNAME (pane), _("Username:"), "user", TRUE);
+    gtk_widget_show (pane);
+    gtk_box_pack_start (GTK_BOX (box), pane, FALSE, FALSE, 0);
     break;
   case AUTH_USERNAME_PASSWORD:
-    {
-      GtkWidget *table, *entry;
-
-      table = gtk_table_new (2, 2, FALSE);
-
-      label = gtk_label_new (_("Username:"));
-      gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
-
-      entry = new_entry_from_gconf (window, info, "user");
-      gtk_table_attach_defaults (GTK_TABLE (table), entry, 1, 2, 0, 1);
-
-      label = gtk_label_new (_("Password:"));
-      gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
-
-      entry = new_entry_from_gconf (window, info, "password");
-      gtk_entry_set_visibility (GTK_ENTRY (entry), FALSE);
-      gtk_table_attach_defaults (GTK_TABLE (table), entry, 1, 2, 1, 2);
-
-      gtk_widget_show_all (table);
-      gtk_box_pack_start (GTK_BOX (box), table, FALSE, FALSE, 0);
-    }
+    pane = bisho_pane_username_new (info);
+    bisho_pane_username_add_entry
+      (BISHO_PANE_USERNAME (pane), _("Username:"), "user", TRUE);
+    bisho_pane_username_add_entry
+      (BISHO_PANE_USERNAME (pane), _("Password:"), "password", FALSE);
+    gtk_widget_show (pane);
+    gtk_box_pack_start (GTK_BOX (box), pane, FALSE, FALSE, 0);
     break;
   case AUTH_OAUTH:
-    {
-      GtkWidget *pane;
-      pane = bisho_pane_oauth_new (info);
-      gtk_widget_show (pane);
-      gtk_box_pack_start (GTK_BOX (box), pane, FALSE, FALSE, 0);
-      g_hash_table_insert (window->priv->panes, info->name, pane);
-    }
+    pane = bisho_pane_oauth_new (window->priv->client, info);
+    gtk_widget_show (pane);
+    gtk_box_pack_start (GTK_BOX (box), pane, FALSE, FALSE, 0);
+    g_hash_table_insert (window->priv->panes, info->name, pane);
     break;
   case AUTH_FLICKR:
-    {
-      GtkWidget *pane;
-      pane = bisho_pane_flickr_new (info);
-      gtk_widget_show (pane);
-      gtk_box_pack_start (GTK_BOX (box), pane, FALSE, FALSE, 0);
-      g_hash_table_insert (window->priv->panes, info->name, pane);
-    }
-    break;
-  case AUTH_FACEBOOK:
-    {
-      GtkWidget *pane;
-      pane = bisho_facebook_pane_new (info);
-      gtk_widget_show (pane);
-      gtk_box_pack_start (GTK_BOX (box), pane, FALSE, FALSE, 0);
-      //g_hash_table_insert (window->priv->panes, info->name, pane);
-    }
+    pane = bisho_pane_flickr_new (window->priv->client, info);
+    gtk_widget_show (pane);
+    gtk_box_pack_start (GTK_BOX (box), pane, FALSE, FALSE, 0);
+    g_hash_table_insert (window->priv->panes, info->name, pane);
     break;
   case AUTH_INVALID:
     /* Should never see this, so ignore it */
@@ -195,17 +128,47 @@ bisho_window_class_init (BishoWindowClass *klass)
 static void
 bisho_window_init (BishoWindow *self)
 {
-  GtkWidget *label;
+#define PACK_IN_TOOL(wid,icon)	{ GtkWidget *tbox; tbox = gtk_hbox_new (FALSE, 0); gtk_box_pack_start ((GtkBox *)tbox, gtk_image_new_from_icon_name(icon, GTK_ICON_SIZE_BUTTON), FALSE, FALSE, 0); wid = (GtkWidget *)gtk_tool_button_new (tbox, NULL); }
+
+  GdkScreen *screen;
+  GtkWidget *box, *toolbar, *label, *quit;
+  GtkToolItem *sep;
 
   self->priv = GET_PRIVATE (self);
 
-  gtk_window_set_title (GTK_WINDOW (self), _("Web Services Settings"));
+  gtk_window_set_title (GTK_WINDOW (self), _("My Web Accounts"));
   gtk_window_set_icon_name (GTK_WINDOW (self), "bisho");
+  gtk_window_set_decorated (GTK_WINDOW (self), FALSE);
+
+  screen = gtk_widget_get_screen (GTK_WIDGET (self));
+  gtk_window_set_default_size (GTK_WINDOW (self),
+                               gdk_screen_get_width (screen),
+                               gdk_screen_get_height (screen));
+
+  box = gtk_vbox_new (FALSE, 0);
+  gtk_widget_show (box);
+  gtk_container_add (GTK_CONTAINER (self), box);
+
+  toolbar = gtk_toolbar_new ();
+  gtk_widget_show (toolbar);
+  gtk_box_pack_start (GTK_BOX (box), toolbar, FALSE, FALSE, 0);
+
+  sep = gtk_separator_tool_item_new ();
+  gtk_separator_tool_item_set_draw (GTK_SEPARATOR_TOOL_ITEM (sep), FALSE);
+  gtk_tool_item_set_expand (GTK_TOOL_ITEM (sep), TRUE);
+  gtk_widget_show (GTK_WIDGET (sep));
+  gtk_toolbar_insert ((GtkToolbar *)toolbar, sep, 0);
+
+  PACK_IN_TOOL (quit, "gtk-close");
+  gtk_widget_set_tooltip_text (quit, _("Quit"));
+  g_signal_connect (quit, "clicked", G_CALLBACK (gtk_main_quit), NULL);
+  gtk_widget_show_all (quit);
+  gtk_toolbar_insert ((GtkToolbar *)toolbar, (GtkToolItem *)quit, -1);
 
   self->priv->master_box = gtk_vbox_new (FALSE, 8);
   gtk_container_set_border_width (GTK_CONTAINER (self->priv->master_box), 8);
   gtk_widget_show (self->priv->master_box);
-  gtk_container_add (GTK_CONTAINER (self), self->priv->master_box);
+  gtk_container_add (GTK_CONTAINER (box), self->priv->master_box);
 
   /* Please don't translate 'myzone' */
   label = gtk_label_new (_("Set up your social networks to see new updates in myzone and the status panel."));
@@ -213,9 +176,6 @@ bisho_window_init (BishoWindow *self)
   gtk_widget_show (label);
   gtk_box_pack_start (GTK_BOX (self->priv->master_box), label, FALSE, FALSE, 0);
 
-  self->priv->banner = mux_banner_new ();
-  gtk_box_pack_start (GTK_BOX (self->priv->master_box), self->priv->banner, FALSE, FALSE, 0);
-
   self->priv->panes = g_hash_table_new (g_str_hash, g_str_equal);
 
   self->priv->client = mojito_client_new ();
@@ -223,21 +183,6 @@ bisho_window_init (BishoWindow *self)
   mojito_client_get_services (self->priv->client, client_get_services_cb, self);
 }
 
-void
-bisho_window_change_banner (BishoWindow *window, ServiceInfo *info)
-{
-  char *s;
-
-  g_return_if_fail (BISHO_IS_WINDOW (window));
-  g_return_if_fail (info);
-
-  s = g_strdup_printf (_("%s login changed."), info->display_name);
-  mux_banner_set_text (MUX_BANNER (window->priv->banner), s);
-  g_free (s);
-
-  gtk_widget_show (window->priv->banner);
-}
-
 GtkWidget *
 bisho_window_new (void)
 {
@@ -254,3 +199,8 @@ bisho_window_callback (BishoWindow *window, const char *id, GHashTable *params)
     bisho_pane_continue_auth (pane, params);
 }
 
+MojitoClient *
+bisho_window_get_mojito (BishoWindow *window)
+{
+  return window->priv->client;
+}
