@@ -37,8 +37,6 @@ service_info_authtype_from_string (const char *s)
     return AUTH_OAUTH;
   } else if (g_ascii_strcasecmp (s, "flickr") == 0) {
     return AUTH_FLICKR;
-  } else if (g_ascii_strcasecmp (s, "facebook") == 0) {
-    return AUTH_FACEBOOK;
   } else {
     g_message ("Unknown authentication type '%s'", s);
     return AUTH_INVALID;
@@ -125,20 +123,6 @@ get_info_for_service (const char *name)
       }
     }
     break;
-  case AUTH_FACEBOOK:
-    {
-      const char *key, *secret;
-
-      if (mojito_keystore_get_key_secret (info->name, &key, &secret)) {
-        info->facebook.app_id = g_strdup (key);
-        info->facebook.secret = g_strdup (secret);
-      } else {
-        g_message ("Cannot find API keys for %s", info->name);
-        /* Yes, we're leaking.  Live with it */
-        return NULL;
-      }
-    }
-    break;
   case AUTH_USERNAME:
   case AUTH_USERNAME_PASSWORD:
   case AUTH_INVALID:
